# mind the upper case 'S' for the name as upstream wants so.
%global binary  shinobi
%global ninja   build.ninja
%global expect  expect.ninja
%global sample  %{name}-sample

Name:           Shinobi
Version:        0.9
Release:        3%{?dist}
Summary:        Meta build system for Ninja

License:        MIT
URL:            https://github.com/Rapptz/%{name}
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source10:       %{sample}

BuildRequires:  boost-devel
BuildRequires:  ninja-build >= 1.3
BuildRequires:  help2man

Requires:       boost-filesystem


%description
%{name} is a meta build system for Ninja, based on C++11 and boost.
It uses an qmake-like structure to configure the output of the
%{ninja} file and implicitly creates the directories specified in
the %{name} file to circumvent the issue Ninja has with building on
non-existing directories. It works by pulling in all .cpp, .cxx, .cc, and
.c++ files and making them into basic build commands. There is also support
for C by allowing .c extensions.


%prep
%setup -q
# ninja: error: ninja.build:1: carriage returns are not allowed, use newline
# rpmlint W: wrong-file-end-of-line-encoding 
sed -i 's,\r$,,' %{ninja} *.txt *.md

%build
# save build file for further reference in check section
cp %{ninja} %{expect}
# FIXME configure: disable bundling, enable debug, locate boost, ignore builddir
# https://github.com/Rapptz/Shinobi/issues/1
sed -e 's,-static,,' -e 's,-DNDEBUG,,' \
 -e 's,\(incflags =\).*,\1 -I. -I%{_includedir}/boost,' \
 -e 's,\(builddir =\).*,\1 .,' \
 -i %{ninja}
ninja-build -v %{?_smp_mflags}
# generate manpage
help2man -o %{binary}.man --version-string=%{version} ./%{binary}

%check
# mock a litte test environment and call binary to produce reference file
mkdir -p test/obj test/util
cp %{SOURCE10} test/%{name}
pushd test
touch util/parser.cpp %{binary}.cpp
../%{binary}
diff ../%{expect} %{ninja}
popd

%install
mkdir -p %{buildroot}%{_bindir}
install -m0755 %{binary} %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_mandir}/man1
gzip -c %{binary}.man > %{buildroot}%{_mandir}/man1/%{binary}.1.gz

%files
%doc LICENSE.txt README.md reference.md
%{_bindir}/%{binary}
%{_mandir}/man1/%{binary}.1.gz


%changelog
* Fri Jan 02 2015 Raphael Groner <projects.rg [AT] smart.ms> - 0.9-3
- add manpage
- cleanup for review

* Sun Dec 21 2014 Raphael Groner <projects.rg [AT] smart.ms> - 0.9-2
- improve comments

* Fri Dec 19 2014 Raphael Groner <projects.rg [AT] smart.ms> - 0.9-1
- initial
